package com.lantone.structure.model.label;

import com.lantone.structure.model.entity.*;
import lombok.Getter;
import lombok.Setter;

import java.util.ArrayList;
import java.util.List;

/**
 * @ClassName : PastLabel
 * @Description : 既往史
 * @Author : 楼辉荣
 * @Date: 2020-03-03 18:45
 */
@Setter
@Getter
public class PastLabel extends GeneralLabel{
    private List<Diag> diags = new ArrayList<>();//疾病史
    private List<Wound> wounds = new ArrayList<>();//外伤史
    private List<DiagInfectious> diagInfectiouses = new ArrayList<>();//传染病史
    private List<Allergy> allergies = new ArrayList<>();//过敏史
    private List<AllergyFood> allergyFoods = new ArrayList<>();//食物过敏史
    private List<AllergyMedicine> allergyMedicines = new ArrayList<>();//药物过敏史
    private List<AllergyDesc> allergyDescs = new ArrayList<>();
    private List<BloodTransfusion> bloodTransfusions = new ArrayList<>();//输血史
    private List<Operation> operations = new ArrayList<>();//手术史
    private List<Vaccinate> vaccinates = new ArrayList<>();//预防接种史
    private String heathCondition;

    public void addDiag(Diag diag) {
        this.diags.add(diag);
    }
    public void addWound(Wound wound) {
        this.wounds.add(wound);
    }
    public void addDiagInfectious(DiagInfectious diagInfectious) {
        this.diagInfectiouses.add(diagInfectious);
    }
    public void addAllergy(Allergy allergy) {
        this.allergies.add(allergy);
    }
    public void addAllergyFood(AllergyFood allergyFood) {
        this.allergyFoods.add(allergyFood);
    }
    public void addAllergyMedicine(AllergyMedicine allergyMedicine) {
        this.allergyMedicines.add(allergyMedicine);
    }
    public void addAllergyDesc(AllergyDesc allergyDesc) {
        this.allergyDescs.add(allergyDesc);
    }
    public void addBloodTransfusion(BloodTransfusion bloodTransfusion) {
        this.bloodTransfusions.add(bloodTransfusion);
    }
    public void addOperation(Operation operation) {
        this.operations.add(operation);
    }
    public void addVaccinate(Vaccinate vaccinate) {
        this.vaccinates.add(vaccinate);
    }
}